@@ -5,11 +5,9 @@ from .onnx_models_structure import (
     DecoderWithLMheadInitial,
 )
 from transformers import (
-    T5Tokenizer,
-    AutoTokenizer,
     AutoConfig,
-    AutoModelForSeq2SeqLM,
     T5ForConditionalGeneration,
+    MT5ForConditionalGeneration,
 )
 import torch
 import functools
@@ -35,7 +33,10 @@ def create_t5_encoder_decoder(pretrained_version="t5-base"):
         decoder_with_lm_head: pytorch t5 decoder with a language modeling head
     """
 
-    model = T5ForConditionalGeneration.from_pretrained(pretrained_version, use_auth_token=get_auth_token())
+    if 'mt5' in pretrained_version:
+        model = MT5ForConditionalGeneration.from_pretrained(pretrained_version, use_auth_token=get_auth_token())
+    else:
+        model = T5ForConditionalGeneration.from_pretrained(pretrained_version, use_auth_token=get_auth_token())
 
     return turn_model_into_encoder_decoder(model)
 
